# Changelog

## [0.1.1](https://github.com/bdesanctis/bamdam/compare/v0.1.0...v0.1.1) (2025-04-07)


### Bug Fixes

* rename release workflow file ([f7790e5](https://github.com/bdesanctis/bamdam/commit/f7790e565bba3940f6fc3d6834685bf4b87a3273))

## 0.1.0 (2025-04-07)


### Miscellaneous Chores

* release 0.1.0 ([f21226a](https://github.com/bdesanctis/bamdam/commit/f21226a36e5aa53ac349a701994ab2002f64abd8))
